@@ -15,7 +15,6 @@ Tests for `pysol_cards` module.
 """
 
 import pysol_cards.random
-
 from pysol_cards.tests import base
 
 
@@ -87,3 +86,52 @@ class TestPysolCards(base.TestCase):
         except ValueError:
             error = True
         self.assertEqual(error, True, "value out of range.")
+
+    def test_ms24_text(self):
+        from pysol_cards.cards import CardRenderer
+        from pysol_cards.deal_game import Game
+        from pysol_cards.random_base import RandomBase
+        ms24s = Game(
+            "freecell", 24,
+            RandomBase.DEALS_MS,
+            max_rank=13
+        ).calc_layout_string(CardRenderer(True))
+        self.assertEqual(
+            ms24s,
+            """4C 2C 9C 8C QS 4S 2H
+5H QH 3C AC 3H 4H QD
+QC 9S 6H 9H 3S KS 3D
+5D 2S JC 5C JH 6D AS
+2D KD TH TC TD 8D
+7H JS KH TS KC 7C
+AH 5S 6S AD 8H JD
+7S 6C 7D 4D 8S 9D
+""",
+            "MS deal #24",
+        )
+
+    def test_ms24_text__using_named_args(self):
+        from pysol_cards.cards import CardRenderer
+        from pysol_cards.deal_game import Game
+        from pysol_cards.random_base import RandomBase
+        ms24s = Game(
+            game_id="freecell",
+            game_num=24,
+            which_deals=RandomBase.DEALS_MS,
+            max_rank=13
+        ).calc_layout_string(
+            CardRenderer(print_ts=True)
+        )
+        self.assertEqual(
+            ms24s,
+            """4C 2C 9C 8C QS 4S 2H
+5H QH 3C AC 3H 4H QD
+QC 9S 6H 9H 3S KS 3D
+5D 2S JC 5C JH 6D AS
+2D KD TH TC TD 8D
+7H JS KH TS KC 7C
+AH 5S 6S AD 8H JD
+7S 6C 7D 4D 8S 9D
+""",
+            "MS deal #24",
+        )
